@@ -13,8 +13,8 @@ do
     cat $f > $(basename $(dirname $(dirname $f))).$(basename $f)
 done
 
-cvs up
+svk add *.packages
 
-cvs add -ko *.packages
+svk ci
 
-cvs ci
+svk smerge --verbatim -l /yada/local /yada/trunk
